@@ -36,7 +36,7 @@ class mTodos(object):
 
   __pretty_app_name__ = "mTodos"
   __app_name__ = "mTodos"
-  __version__ = "0.2.1"
+  __version__ = "0.2.2"
   __context__ = "net.khertan.mtodos"
 
   _glade_files = [
@@ -233,7 +233,7 @@ class mTodos(object):
 #      task.save_to_db()
 #      self.refresh()
   def _if_all_false(self,widget):
-    if (self._widgetTree.get_widget("bNow").get_active()==False) and (self._widgetTree.get_widget("bNext").get_active()==False) and (self._widgetTree.get_widget("bFuture").get_active()==False):
+    if (self._widgetTree.get_widget("bNow").get_active()==False) and (self._widgetTree.get_widget("bNext").get_active()==False) and (self._widgetTree.get_widget("bFuture").get_active()==False) and (self._current_view!=4):
       widget.set_active(True)
 
   def _show_now(self,widget):
